@@ -1,11 +1,10 @@
 app_buttons <- 'box(
-  width = NULL,
   title = "App Buttons",
-  status = NULL,
+  width = 12,
   appButton(
     inputId = "myAppButton",
     label = "Users", 
     icon = icon("users"), 
-    dashboardBadge(textOutput("appBtnVal"))
+    dashboardBadge(textOutput("appBtnVal"), color = "maroon")
   )
 )'
\ No newline at end of file
