@@ -1212,61 +1212,62 @@ $(function() {
 });
 
 $(function() {
-  
   // box vertical overflow
   $(".content-wrapper").css("overflow-y", "auto");
 
   // slide to top button
-  var $slideToTop = $("<div />");
+  if ($("body").attr("data-scrollToTop") == 1) {
+    var $slideToTop = $("<div />");
 
-  $slideToTop.html('<i class="fa fa-chevron-up"></i>');
+    $slideToTop.html('<i class="fa fa-chevron-up"></i>');
 
-  $slideToTop.css({
-    position: "fixed",
-    bottom: "20px",
-    right: "25px",
-    width: "40px",
-    height: "40px",
-    color: "#eee",
-    "font-size": "",
-    "line-height": "40px",
-    "text-align": "center",
-    "background-color": "#222d32",
-    cursor: "pointer",
-    "border-radius": "5px",
-    "z-index": "99999",
-    opacity: ".7",
-    display: "none"
-  });
+    $slideToTop.css({
+      position: "fixed",
+      bottom: "20px",
+      right: "25px",
+      width: "40px",
+      height: "40px",
+      color: "#eee",
+      "font-size": "",
+      "line-height": "40px",
+      "text-align": "center",
+      "background-color": "#222d32",
+      cursor: "pointer",
+      "border-radius": "5px",
+      "z-index": "99999",
+      opacity: ".7",
+      display: "none"
+    });
 
-  $slideToTop.on("mouseenter", function() {
-    $(this).css("opacity", "1");
-  });
+    $slideToTop.on("mouseenter", function() {
+      $(this).css("opacity", "1");
+    });
 
-  $slideToTop.on("mouseout", function() {
-    $(this).css("opacity", ".7");
-  });
+    $slideToTop.on("mouseout", function() {
+      $(this).css("opacity", ".7");
+    });
 
-  $(".wrapper").append($slideToTop);
+    $(".wrapper").append($slideToTop);
 
-  $(window).scroll(function() {
-    if ($(window).scrollTop() >= 150) {
-      if (!$($slideToTop).is(":visible")) {
-        $($slideToTop).fadeIn(500);
+    $(window).scroll(function() {
+      if ($(window).scrollTop() >= 150) {
+        if (!$($slideToTop).is(":visible")) {
+          $($slideToTop).fadeIn(500);
+        }
+      } else {
+        $($slideToTop).fadeOut(500);
       }
-    } else {
-      $($slideToTop).fadeOut(500);
-    }
-  });
+    });
 
-  $($slideToTop).click(function() {
-    $("html, body").animate(
-      {
-        scrollTop: 0
-      },
-      500
-    );
-  });
+    $($slideToTop).click(function() {
+      $("html, body").animate(
+        {
+          scrollTop: 0
+        },
+        500
+      );
+    });
+  }
 
   // code to make sure that a carousel item is displayed
   // when it is generated via a shiny Output function
@@ -1335,7 +1336,7 @@ var navPillsBinding = new Shiny.InputBinding();
 
 $.extend(navPillsBinding, {
   find: function(scope) {
-    return $(scope).find(".nav.nav-pills.nav-stacked");
+    return $(scope).find(".nav.nav-pills.nav-stacked.shinydashboardplus-custom");
   },
   // Given the DOM element for the input, return the value
   getValue: function(el) {
